aboutsummaryrefslogtreecommitdiffstats
path: root/engine/overworld/player_animations.asm
diff options
context:
space:
mode:
authorYamaArashi <shadow962@live.com>2015-07-24 20:27:59 -0700
committerYamaArashi <shadow962@live.com>2015-07-24 20:27:59 -0700
commit7f6d0d49b61a77cfba76057d99881634b882486b (patch)
treeafb152986ff34039cb64e3101dd2b2b1e3293552 /engine/overworld/player_animations.asm
parentnamed more functions (diff)
downloadpokeyellow-7f6d0d49b61a77cfba76057d99881634b882486b.tar.gz
pokeyellow-7f6d0d49b61a77cfba76057d99881634b882486b.tar.xz
pokeyellow-7f6d0d49b61a77cfba76057d99881634b882486b.zip
more naming variables
Diffstat (limited to 'engine/overworld/player_animations.asm')
-rwxr-xr-xengine/overworld/player_animations.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/overworld/player_animations.asm b/engine/overworld/player_animations.asm
index a9aa2cf2..1a3d374f 100755
--- a/engine/overworld/player_animations.asm
+++ b/engine/overworld/player_animations.asm
@@ -370,10 +370,10 @@ IsPlayerStandingOnWarpPadOrHole: ; 70787 (1c:4787)
ld b, [hl]
.done
ld a, b
- ld [wcd5b], a
+ ld [wStandingOnWarpPadOrHole], a
ret
; format: db tileset id, tile id, value to be put in wcd5b
.warpPadAndHoleData: ; 707a9 (1c:47a9)
db FACILITY, $20, 1 ; warp pad
db FACILITY, $11, 2 ; hole
@@ -370,10 +370,10 @@ IsPlayerStandingOnWarpPadOrHole: ; 70787 (1c:4787)
ret
-; format: db tileset id, tile id, value to be put in wcd5b
+; format: db tileset id, tile id, value to be put in [wStandingOnWarpPadOrHole]
.warpPadAndHoleData: ; 707a9 (1c:47a9)
db FACILITY, $20, 1 ; warp pad